==> aliyun-java-sdk-iot-5.0.0-sources.jar: com/aliyuncs/iot/model/v20180120/QueryDeviceStatisticsResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.iot.model.v20180120;

import com.aliyuncs.AcsResponse;
import com.aliyuncs.iot.transform.v20180120.QueryDeviceStatisticsResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class QueryDeviceStatisticsResponse extends AcsResponse {

	private String requestId;

	private Boolean success;

	private String errorMessage;

	private Data data;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public Boolean getSuccess() {
		return this.success;
	}

	public void setSuccess(Boolean success) {
		this.success = success;
	}

	public String getErrorMessage() {
		return this.errorMessage;
	}

	public void setErrorMessage(String errorMessage) {
		this.errorMessage = errorMessage;
	}

	public Data getData() {
		return this.data;
	}

	public void setData(Data data) {
		this.data = data;
	}

	public static class Data {

		private Long deviceCount;

		private Long onlineCount;

		private Long activeCount;

		public Long getDeviceCount() {
			return this.deviceCount;
		}

		public void setDeviceCount(Long deviceCount) {
			this.deviceCount = deviceCount;
		}

		public Long getOnlineCount() {
			return this.onlineCount;
		}

		public void setOnlineCount(Long onlineCount) {
			this.onlineCount = onlineCount;
		}

		public Long getActiveCount() {
			return this.activeCount;
		}

		public void setActiveCount(Long activeCount) {
			this.activeCount = activeCount;
		}
	}

	@Override
	public QueryDeviceStatisticsResponse getInstance(UnmarshallerContext context) {
		return	QueryDeviceStatisticsResponseUnmarshaller.unmarshall(this, context);
	}
}

==> aliyun-java-sdk-iot-7.18.0-sources.jar: com/aliyuncs/iot/model/v20180120/QueryDeviceStatisticsResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.iot.model.v20180120;

import com.aliyuncs.AcsResponse;
import com.aliyuncs.iot.transform.v20180120.QueryDeviceStatisticsResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class QueryDeviceStatisticsResponse extends AcsResponse {

	private String requestId;

	private Boolean success;

	private String code;

	private String errorMessage;

	private Data data;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public Boolean getSuccess() {
		return this.success;
	}

	public void setSuccess(Boolean success) {
		this.success = success;
	}

	public String getCode() {
		return this.code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getErrorMessage() {
		return this.errorMessage;
	}

	public void setErrorMessage(String errorMessage) {
		this.errorMessage = errorMessage;
	}

	public Data getData() {
		return this.data;
	}

	public void setData(Data data) {
		this.data = data;
	}

	public static class Data {

		private Long deviceCount;

		private Long onlineCount;

		private Long activeCount;

		public Long getDeviceCount() {
			return this.deviceCount;
		}

		public void setDeviceCount(Long deviceCount) {
			this.deviceCount = deviceCount;
		}

		public Long getOnlineCount() {
			return this.onlineCount;
		}

		public void setOnlineCount(Long onlineCount) {
			this.onlineCount = onlineCount;
		}

		public Long getActiveCount() {
			return this.activeCount;
		}

		public void setActiveCount(Long activeCount) {
			this.activeCount = activeCount;
		}
	}

	@Override
	public QueryDeviceStatisticsResponse getInstance(UnmarshallerContext context) {
		return	QueryDeviceStatisticsResponseUnmarshaller.unmarshall(this, context);
	}
}
